@@ -48,7 +48,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateCustomCategory(self, request):
@@ -74,7 +74,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateCustomGroup(self, request):
@@ -107,7 +107,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateCustomPerson(self, request):
@@ -134,7 +134,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateDefaultCategories(self, request):
@@ -157,7 +157,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateTask(self, request):
@@ -182,7 +182,54 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateVideoSummaryTask(self, request):
+        """创建一个视频缩编任务。
+
+        ### 回调事件消息通知协议
+
+        #### 网络协议
+        - 回调接口协议目前仅支持http/https协议；
+        - 请求：HTTP POST 请求，包体内容为 JSON，每一种消息的具体包体内容参见后文。
+        - 应答：HTTP STATUS CODE = 200，服务端忽略应答包具体内容，为了协议友好，建议客户应答内容携带 JSON： `{"code":0}`
+
+        #### 通知可靠性
+
+        事件通知服务具备重试能力，事件通知失败后会总计重试3次；
+        为了避免重试对您的服务器以及网络带宽造成冲击，请保持正常回包。触发重试条件如下：
+        - 长时间（5 秒）未回包应答。
+        - 应答 HTTP STATUS 不为200。
+
+
+        #### 回调接口协议
+
+        ##### 分析任务完成消息回调
+        | 参数名称 | 必选 | 类型 | 描述 |
+        |---------|---------|---------|---------|
+        | TaskId | 是 | String | 任务ID |
+        | TaskStatus | 是 | Integer | 任务执行状态 |
+        | FailedReason | 是 | String | 若任务失败，该字段为失败原因 |
+
+        :param request: Request instance for CreateVideoSummaryTask.
+        :type request: :class:`tencentcloud.ivld.v20210903.models.CreateVideoSummaryTaskRequest`
+        :rtype: :class:`tencentcloud.ivld.v20210903.models.CreateVideoSummaryTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateVideoSummaryTask", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateVideoSummaryTaskResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteCustomCategory(self, request):
@@ -205,7 +252,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteCustomPerson(self, request):
@@ -228,7 +275,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteCustomPersonImage(self, request):
@@ -251,7 +298,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteMedia(self, request):
@@ -276,7 +323,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteTask(self, request):
@@ -303,7 +350,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCustomCategories(self, request):
@@ -326,7 +373,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCustomGroup(self, request):
@@ -349,7 +396,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCustomPersonDetail(self, request):
@@ -372,7 +419,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCustomPersons(self, request):
@@ -396,7 +443,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeMedia(self, request):
@@ -421,7 +468,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeMedias(self, request):
@@ -448,7 +495,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeTask(self, request):
@@ -456,7 +503,6 @@ class IvldClient(AbstractClient):
 
         请注意，**此接口仅返回任务执行状态信息，不返回任务执行结果**
 
-
         :param request: Request instance for DescribeTask.
         :type request: :class:`tencentcloud.ivld.v20210903.models.DescribeTaskRequest`
         :rtype: :class:`tencentcloud.ivld.v20210903.models.DescribeTaskResponse`
@@ -474,7 +520,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeTaskDetail(self, request):
@@ -497,7 +543,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeTasks(self, request):
@@ -522,7 +568,53 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeUsageAmount(self, request):
+        """获取用户资源使用量
+
+        :param request: Request instance for DescribeUsageAmount.
+        :type request: :class:`tencentcloud.ivld.v20210903.models.DescribeUsageAmountRequest`
+        :rtype: :class:`tencentcloud.ivld.v20210903.models.DescribeUsageAmountResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeUsageAmount", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeUsageAmountResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeVideoSummaryDetail(self, request):
+        """描述任务信息，如果任务成功完成，还将返回任务结果
+
+        :param request: Request instance for DescribeVideoSummaryDetail.
+        :type request: :class:`tencentcloud.ivld.v20210903.models.DescribeVideoSummaryDetailRequest`
+        :rtype: :class:`tencentcloud.ivld.v20210903.models.DescribeVideoSummaryDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeVideoSummaryDetail", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeVideoSummaryDetailResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ImportMedia(self, request):
@@ -553,7 +645,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyCallback(self, request):
@@ -610,7 +702,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def QueryCallback(self, request):
@@ -633,7 +725,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateCustomCategory(self, request):
@@ -659,7 +751,7 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateCustomPerson(self, request):
@@ -682,4 +774,4 @@ class IvldClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
\ No newline at end of file
+                raise TencentCloudSDKException(type(e).__name__, str(e))
\ No newline at end of file
